@@ -13,8 +13,8 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-02111-1307, USA.  */
+Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+02110-1301, USA.  */
 
 #include <stdio.h>
 #include <unistd.h>
@@ -29,6 +29,13 @@ main (int argc, const char * argv[])
 	FILE *fp;
 	int r;
 
+	if (argc != 1)
+	  {
+	    fprintf (stderr, "usage: %s\n", (argv[0]));
+	    fflush (stderr);
+	    exit (2);
+	  }
+
 	r = access(APM_PROC, R_OK);
 	if (r==0)
 		exit(0);
